/*
 * Copyright (c) 2007 - 2009 NVIDIA Corporation.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *  * Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *  * Neither the name of NVIDIA CORPORATION nor the names of its
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Defines version information for the boot rom.
 */

#ifndef INCLUDED_NVBOOT_VERSION_H
#define INCLUDED_NVBOOT_VERSION_H

#include "nvboot_version_defs.h"

/***********************************************************************/
/* !!!!!   THIS FILE SHOULD NOT BE INCLUDED IN BOOTROM SOURCE    !!!!! */
/* !!!!!   THIS FILE SHOULD NOT BE INCLUDED IN BOOTROM SOURCE    !!!!! */
/* !!!!!   THIS FILE SHOULD NOT BE INCLUDED IN BOOTROM SOURCE    !!!!! */
/* !!!!!   THIS FILE SHOULD NOT BE INCLUDED IN BOOTROM SOURCE    !!!!! */
/*								       */
/*         Use nvboot_version_rom.h				       */
/*								       */
/***********************************************************************/

#define NVBOOT_BOOTROM_VERSION		CONST_NVBOOT_BOOTROM_VERSION
#define NVBOOT_RCM_VERSION	 	CONST_NVBOOT_RCM_VERSION
#define NVBOOT_BOOTDATA_VERSION		CONST_NVBOOT_BOOTDATA_VERSION

/**
 * Constants for the version numbers of each chip revision.
 */

/**
 * BootROM versions for each chip revision
 */
#define NVBOOT_BOOTROM_VERSION_AP15_A01_MAJOR 1
#define NVBOOT_BOOTROM_VERSION_AP15_A01_MINOR 0
#define NVBOOT_BOOTROM_VERSION_AP15_A01                 \
  (NVBOOT_VERSION(NVBOOT_BOOTROM_VERSION_AP15_A01_MAJOR,\
                  NVBOOT_BOOTROM_VERSION_AP15_A01_MINOR))

#define NVBOOT_BOOTROM_VERSION_AP15_A02_MAJOR 1
#define NVBOOT_BOOTROM_VERSION_AP15_A02_MINOR 1
#define NVBOOT_BOOTROM_VERSION_AP15_A02                 \
  (NVBOOT_VERSION(NVBOOT_BOOTROM_VERSION_AP15_A02_MAJOR,\
                  NVBOOT_BOOTROM_VERSION_AP15_A02_MINOR))

#define NVBOOT_BOOTROM_VERSION_AP16_A01_MAJOR 1
#define NVBOOT_BOOTROM_VERSION_AP16_A01_MINOR 2
#define NVBOOT_BOOTROM_VERSION_AP16_A01                 \
  (NVBOOT_VERSION(NVBOOT_BOOTROM_VERSION_AP16_A01_MAJOR,\
                  NVBOOT_BOOTROM_VERSION_AP16_A01_MINOR))

#define NVBOOT_BOOTROM_VERSION_AP16_A02_MAJOR 1
#define NVBOOT_BOOTROM_VERSION_AP16_A02_MINOR 2
#define NVBOOT_BOOTROM_VERSION_AP16_A02                 \
  (NVBOOT_VERSION(NVBOOT_BOOTROM_VERSION_AP16_A02_MAJOR,\
                  NVBOOT_BOOTROM_VERSION_AP16_A02_MINOR))

#define NVBOOT_BOOTROM_VERSION_AP16_A03_MAJOR 1
#define NVBOOT_BOOTROM_VERSION_AP16_A03_MINOR 3
#define NVBOOT_BOOTROM_VERSION_AP16_A03                 \
  (NVBOOT_VERSION(NVBOOT_BOOTROM_VERSION_AP16_A03_MAJOR,\
                  NVBOOT_BOOTROM_VERSION_AP16_A03_MINOR))

#define NVBOOT_BOOTROM_VERSION_AP20_A01_MAJOR 2
#define NVBOOT_BOOTROM_VERSION_AP20_A01_MINOR 1
#define NVBOOT_BOOTROM_VERSION_AP20_A01                 \
  (NVBOOT_VERSION(NVBOOT_BOOTROM_VERSION_AP20_A01_MAJOR,\
                  NVBOOT_BOOTROM_VERSION_AP20_A01_MINOR))

#define NVBOOT_BOOTROM_VERSION_T30_A01_MAJOR 3
#define NVBOOT_BOOTROM_VERSION_T30_A01_MINOR 1
#define NVBOOT_BOOTROM_VERSION_T30_A01                 \
  (NVBOOT_VERSION(NVBOOT_BOOTROM_VERSION_T30_A01_MAJOR,\
                  NVBOOT_BOOTROM_VERSION_T30_A01_MINOR))

/**
 * RCM versions for each chip revision
 */
#define NVBOOT_RCM_VERSION_AP15_A01_MAJOR 1
#define NVBOOT_RCM_VERSION_AP15_A01_MINOR 0
#define NVBOOT_RCM_VERSION_AP15_A01                 \
  (NVBOOT_VERSION(NVBOOT_RCM_VERSION_AP15_A01_MAJOR,\
                  NVBOOT_RCM_VERSION_AP15_A01_MINOR))

#define NVBOOT_RCM_VERSION_AP15_A02_MAJOR 1
#define NVBOOT_RCM_VERSION_AP15_A02_MINOR 0
#define NVBOOT_RCM_VERSION_AP15_A02                 \
  (NVBOOT_VERSION(NVBOOT_RCM_VERSION_AP15_A02_MAJOR,\
                  NVBOOT_RCM_VERSION_AP15_A02_MINOR))

#define NVBOOT_RCM_VERSION_AP16_A01_MAJOR 1
#define NVBOOT_RCM_VERSION_AP16_A01_MINOR 0
#define NVBOOT_RCM_VERSION_AP16_A01                 \
  (NVBOOT_VERSION(NVBOOT_RCM_VERSION_AP16_A01_MAJOR,\
                  NVBOOT_RCM_VERSION_AP16_A01_MINOR))

#define NVBOOT_RCM_VERSION_AP16_A02_MAJOR 1
#define NVBOOT_RCM_VERSION_AP16_A02_MINOR 0
#define NVBOOT_RCM_VERSION_AP16_A02                 \
  (NVBOOT_VERSION(NVBOOT_RCM_VERSION_AP16_A02_MAJOR,\
                  NVBOOT_RCM_VERSION_AP16_A02_MINOR))

#define NVBOOT_RCM_VERSION_AP16_A03_MAJOR 1
#define NVBOOT_RCM_VERSION_AP16_A03_MINOR 0
#define NVBOOT_RCM_VERSION_AP16_A03                 \
  (NVBOOT_VERSION(NVBOOT_RCM_VERSION_AP16_A03_MAJOR,\
                  NVBOOT_RCM_VERSION_AP16_A03_MINOR))

#define NVBOOT_RCM_VERSION_AP20_A01_MAJOR 2
#define NVBOOT_RCM_VERSION_AP20_A01_MINOR 1
#define NVBOOT_RCM_VERSION_AP20_A01                 \
  (NVBOOT_VERSION(NVBOOT_RCM_VERSION_AP20_A01_MAJOR,\
                  NVBOOT_RCM_VERSION_AP20_A01_MINOR))

#define NVBOOT_RCM_VERSION_T30_A01_MAJOR 3
#define NVBOOT_RCM_VERSION_T30_A01_MINOR 1
#define NVBOOT_RCM_VERSION_T30_A01                 \
  (NVBOOT_VERSION(NVBOOT_RCM_VERSION_T30_A01_MAJOR,\
                  NVBOOT_RCM_VERSION_T30_A01_MINOR))

/**
 * BootData versions for each chip revision
 */
#define NVBOOT_BOOTDATA_VERSION_AP15_A01_MAJOR 1
#define NVBOOT_BOOTDATA_VERSION_AP15_A01_MINOR 0
#define NVBOOT_BOOTDATA_VERSION_AP15_A01                 \
  (NVBOOT_VERSION(NVBOOT_BOOTDATA_VERSION_AP15_A01_MAJOR,\
                  NVBOOT_BOOTDATA_VERSION_AP15_A01_MINOR))

#define NVBOOT_BOOTDATA_VERSION_AP15_A02_MAJOR 1
#define NVBOOT_BOOTDATA_VERSION_AP15_A02_MINOR 0
#define NVBOOT_BOOTDATA_VERSION_AP15_A02                 \
  (NVBOOT_VERSION(NVBOOT_BOOTDATA_VERSION_AP15_A02_MAJOR,\
                  NVBOOT_BOOTDATA_VERSION_AP15_A02_MINOR))

#define NVBOOT_BOOTDATA_VERSION_AP16_A01_MAJOR 1
#define NVBOOT_BOOTDATA_VERSION_AP16_A01_MINOR 0
#define NVBOOT_BOOTDATA_VERSION_AP16_A01                 \
  (NVBOOT_VERSION(NVBOOT_BOOTDATA_VERSION_AP16_A01_MAJOR,\
                  NVBOOT_BOOTDATA_VERSION_AP16_A01_MINOR))

#define NVBOOT_BOOTDATA_VERSION_AP16_A02_MAJOR 1
#define NVBOOT_BOOTDATA_VERSION_AP16_A02_MINOR 0
#define NVBOOT_BOOTDATA_VERSION_AP16_A02                 \
  (NVBOOT_VERSION(NVBOOT_BOOTDATA_VERSION_AP16_A02_MAJOR,\
                  NVBOOT_BOOTDATA_VERSION_AP16_A02_MINOR))

#define NVBOOT_BOOTDATA_VERSION_AP16_A03_MAJOR 1
#define NVBOOT_BOOTDATA_VERSION_AP16_A03_MINOR 0
#define NVBOOT_BOOTDATA_VERSION_AP16_A03                 \
  (NVBOOT_VERSION(NVBOOT_BOOTDATA_VERSION_AP16_A03_MAJOR,\
                  NVBOOT_BOOTDATA_VERSION_AP16_A03_MINOR))

#define NVBOOT_BOOTDATA_VERSION_AP20_A01_MAJOR 2
#define NVBOOT_BOOTDATA_VERSION_AP20_A01_MINOR 1
#define NVBOOT_BOOTDATA_VERSION_AP20_A01                 \
  (NVBOOT_VERSION(NVBOOT_BOOTDATA_VERSION_AP20_A01_MAJOR,\
                  NVBOOT_BOOTDATA_VERSION_AP20_A01_MINOR))

#define NVBOOT_BOOTDATA_VERSION_T30_A01_MAJOR 3
#define NVBOOT_BOOTDATA_VERSION_T30_A01_MINOR 1
#define NVBOOT_BOOTDATA_VERSION_T30_A01                 \
  (NVBOOT_VERSION(NVBOOT_BOOTDATA_VERSION_T30_A01_MAJOR,\
                  NVBOOT_BOOTDATA_VERSION_T30_A01_MINOR))

/***********************************************************************/
/* !!!!!   THIS FILE SHOULD NOT BE INCLUDED IN BOOTROM SOURCE    !!!!! */
/* !!!!!   THIS FILE SHOULD NOT BE INCLUDED IN BOOTROM SOURCE    !!!!! */
/* !!!!!   THIS FILE SHOULD NOT BE INCLUDED IN BOOTROM SOURCE    !!!!! */
/***********************************************************************/


#endif /* #ifndef INCLUDED_NVBOOT_VERSION_H */
